==> jc-1.4.0.tar.gz: soot/grimp/internal/GOrExpr.h <==
// public class soot.grimp.internal.GOrExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5db408cd5e821f4f soot_grimp_internal_AbstractGrimpIntLongBinopExpr
// @dep_class c667afc22bbe6d70 soot_grimp_internal_GOrExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpIntLongBinopExpr

#include "soot/grimp/internal/AbstractGrimpIntLongBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GOrExpr_H_
#define _JC_soot_grimp_internal_GOrExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GOrExpr$sub_refs	_jc_soot_grimp_internal_GOrExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GOrExpr$sub_nonrefs	_jc_soot_grimp_internal_GOrExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GOrExpr$refs	_jc_soot_grimp_internal_GOrExpr$refs;
typedef struct _jc_soot_grimp_internal_GOrExpr$nonrefs	_jc_soot_grimp_internal_GOrExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GOrExpr$object	_jc_soot_grimp_internal_GOrExpr$object;

typedef const struct _jc_soot_grimp_internal_GOrExpr$vmethods	_jc_soot_grimp_internal_GOrExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GOrExpr$vtable	_jc_soot_grimp_internal_GOrExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GOrExpr$vtype	_jc_soot_grimp_internal_GOrExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GOrExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_grimp_internal_GOrExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GOrExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *);
extern jint _jc_soot_grimp_internal_GOrExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GOrExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GOrExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GOrExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
	_jc_soot_grimp_internal_GOrExpr$vmethods	soot_grimp_internal_GOrExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GOrExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GOrExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GOrExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GOrExpr$refs {
    _jc_soot_grimp_internal_GOrExpr$sub_refs	soot_grimp_internal_GOrExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GOrExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GOrExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_grimp_internal_GOrExpr$sub_nonrefs	soot_grimp_internal_GOrExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GOrExpr$object {
	_jc_soot_grimp_internal_GOrExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GOrExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GOrExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GOrExpr$vtype _jc_soot_grimp_internal_GOrExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GOrExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GOrExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GOrExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GOrExpr.h <==
// public class soot.grimp.internal.GOrExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5db408cd5e821f4f soot_grimp_internal_AbstractGrimpIntLongBinopExpr
// @dep_class c667afc22bbe6d70 soot_grimp_internal_GOrExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpIntLongBinopExpr

#include "soot/grimp/internal/AbstractGrimpIntLongBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GOrExpr_H_
#define _JC_soot_grimp_internal_GOrExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GOrExpr$sub_refs	_jc_soot_grimp_internal_GOrExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GOrExpr$sub_nonrefs	_jc_soot_grimp_internal_GOrExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GOrExpr$refs	_jc_soot_grimp_internal_GOrExpr$refs;
typedef struct _jc_soot_grimp_internal_GOrExpr$nonrefs	_jc_soot_grimp_internal_GOrExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GOrExpr$object	_jc_soot_grimp_internal_GOrExpr$object;

typedef const struct _jc_soot_grimp_internal_GOrExpr$vmethods	_jc_soot_grimp_internal_GOrExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GOrExpr$vtable	_jc_soot_grimp_internal_GOrExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GOrExpr$vtype	_jc_soot_grimp_internal_GOrExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GOrExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_grimp_internal_GOrExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GOrExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GOrExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GOrExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GOrExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GOrExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GOrExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GOrExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
	_jc_soot_grimp_internal_GOrExpr$vmethods	soot_grimp_internal_GOrExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GOrExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GOrExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GOrExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GOrExpr$refs {
    _jc_soot_grimp_internal_GOrExpr$sub_refs	soot_grimp_internal_GOrExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GOrExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GOrExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_grimp_internal_GOrExpr$sub_nonrefs	soot_grimp_internal_GOrExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GOrExpr$object {
	_jc_soot_grimp_internal_GOrExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GOrExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GOrExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GOrExpr$vtype _jc_soot_grimp_internal_GOrExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GOrExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GOrExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GOrExpr_H_ */
